<?php

namespace apexl\Io\modules\admin\controllers;

use apexl\Io\includes\Controller;

class systemController extends Controller{
    public function __construct()
    {
        parent::__construct();
    }


}